#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_NOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_NOT_HPP_INCLUDED

#include <nt2/operator/include/functions/logical_not.hpp>

#endif
